==> plugin-android-3.0.2-sources.jar: com/zoyi/channel/plugin/android/activity/chat/viewholder/BaseMessageHolder.java <==
package com.zoyi.channel.plugin.android.activity.chat.viewholder;

import android.content.Context;
import android.support.v7.widget.RecyclerView;
import android.view.Gravity;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.LinearLayout;
import android.widget.TextView;

import com.zoyi.channel.plugin.android.R;
import com.zoyi.channel.plugin.android.activity.chat.ChatDataDictionary;
import com.zoyi.channel.plugin.android.activity.chat.type.MessageType;
import com.zoyi.channel.plugin.android.model.interfaces.ProfileEntity;
import com.zoyi.channel.plugin.android.model.rest.Message;
import com.zoyi.channel.plugin.android.util.TimeUtils;
import com.zoyi.channel.plugin.android.util.UIUtils;
import com.zoyi.channel.plugin.android.util.Utils;
import com.zoyi.channel.plugin.android.view.layout.AvatarLayout;

/**
 * Created by jerry on 2018. 3. 28..
 */

public class BaseMessageHolder extends RecyclerView.ViewHolder {

  TextView guestMessageTime;
  LinearLayout guestMessageTextLayout;

  LinearLayout managerMessageProfileLayout;
  AvatarLayout managerMessageAvatar;
  TextView managerMessageName;
  TextView managerMessageTime;
  LinearLayout managerMessageTextLayout;

  LinearLayout contentLayout;

  private Context context;

  public static BaseMessageHolder newInstance(ViewGroup parent, MessageType messageType) {
    return new BaseMessageHolder(getItemView(parent, messageType), messageType);
  }

  public BaseMessageHolder(View itemView, MessageType messageType) {
    super(itemView);
    this.context = itemView.getContext();

    switch (messageType) {
      case GUEST_TEXT_MESSAGE:
      case GUEST_IMAGE_MESSAGE:
      case GUEST_FILE_MESSAGE:
      case GUEST_WEB_MESSAGE:
      case SENDING:
        guestMessageTime = itemView.findViewById(R.id.ch_text_guest_message_time);
        guestMessageTextLayout = itemView.findViewById(R.id.ch_message_content_guest_text);
        break;

      default:
        managerMessageProfileLayout = itemView.findViewById(R.id.ch_layout_manager_message_profile);
        managerMessageAvatar = itemView.findViewById(R.id.ch_avater_manager_message);
        managerMessageTime = itemView.findViewById(R.id.ch_text_manager_message_time);
        managerMessageName = itemView.findViewById(R.id.ch_text_manager_message_name);
        managerMessageTextLayout = itemView.findViewById(R.id.ch_message_content_manager_text);
        break;
    }
    contentLayout = itemView.findViewById(R.id.ch_layout_message_content);
  }

  protected static View getItemView(ViewGroup parent, MessageType messageType) {
    LayoutInflater inflater = LayoutInflater.from(parent.getContext());

    switch (messageType) {
      case GUEST_TEXT_MESSAGE:
      case GUEST_IMAGE_MESSAGE:
      case GUEST_FILE_MESSAGE:
      case GUEST_WEB_MESSAGE:
      case SENDING:
        return inflater.inflate(R.layout.ch_plugin_item_message_guest, parent, false);

      default:
        return inflater.inflate(R.layout.ch_plugin_item_message_manager2, parent, false);
    }
  }

  public void bind(Message message, MessageType messageType, boolean isConnectedMessage) {
    setLayout(message, messageType, isConnectedMessage);
  }

  private void setLayout(Message message, MessageType messageType, boolean isConnectedMessage) {
    switch (messageType) {
      case GUEST_TEXT_MESSAGE:
      case GUEST_IMAGE_MESSAGE:
      case GUEST_FILE_MESSAGE:
      case GUEST_WEB_MESSAGE:
      case SENDING:
        setGuestMessage(message, isConnectedMessage);
        break;

      default:
        setManagerMessage(message, isConnectedMessage);
        break;
    }
  }

  private void setGuestMessage(Message message, boolean isConnectedMessage) {
    if (message != null) {
      guestMessageTime.setVisibility(UIUtils.getVisible(!isConnectedMessage, true));
      guestMessageTime.setText(TimeUtils.getTime(message.getCreatedAt()));

      LinearLayout.LayoutParams params = new LinearLayout.LayoutParams(
          ViewGroup.LayoutParams.MATCH_PARENT,
          ViewGroup.LayoutParams.WRAP_CONTENT);
      params.gravity = Gravity.END;
      contentLayout.setGravity(Gravity.END);
      contentLayout.setLayoutParams(params);
    }
  }

  private void setManagerMessage(Message message, boolean isConnectedMessage) {
    if (message != null) {
      ProfileEntity profile = ChatDataDictionary
          .getInstance()
          .getProfile(message.getPersonType(), message.getPersonId());

      managerMessageProfileLayout.setVisibility(UIUtils.getVisible(!isConnectedMessage, true));
      managerMessageAvatar.set(profile);
      managerMessageTime.setText(TimeUtils.getTime(message.getCreatedAt()));
      managerMessageName.setText(profile.getName());

      LinearLayout.LayoutParams params = new LinearLayout.LayoutParams(
          ViewGroup.LayoutParams.MATCH_PARENT,
          ViewGroup.LayoutParams.WRAP_CONTENT);
      params.leftMargin = (int) Utils.dpToPx(context, 46);
      contentLayout.setLayoutParams(params);
    }
  }
}

==> plugin-android-3.1.3-sources.jar: com/zoyi/channel/plugin/android/activity/chat/viewholder/BaseMessageHolder.java <==
package com.zoyi.channel.plugin.android.activity.chat.viewholder;

import android.content.Context;
import android.support.v7.widget.RecyclerView;
import android.view.Gravity;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.LinearLayout;
import android.widget.TextView;

import com.zoyi.channel.plugin.android.R;
import com.zoyi.channel.plugin.android.activity.chat.ChatDataDictionary;
import com.zoyi.channel.plugin.android.activity.chat.type.MessageType;
import com.zoyi.channel.plugin.android.model.interfaces.ProfileEntity;
import com.zoyi.channel.plugin.android.model.rest.Message;
import com.zoyi.channel.plugin.android.util.TimeUtils;
import com.zoyi.channel.plugin.android.util.UIUtils;
import com.zoyi.channel.plugin.android.util.Utils;
import com.zoyi.channel.plugin.android.view.layout.AvatarLayout;
import com.zoyi.channel.plugin.android.view.layout.CHTextView;

/**
 * Created by jerry on 2018. 3. 28..
 */

public class BaseMessageHolder extends RecyclerView.ViewHolder {

  CHTextView guestMessageTime;
  LinearLayout guestMessageTextLayout;

  LinearLayout managerMessageProfileLayout;
  AvatarLayout managerMessageAvatar;
  CHTextView managerMessageName;
  CHTextView managerMessageTime;
  LinearLayout managerMessageTextLayout;

  LinearLayout contentLayout;

  private Context context;

  public static BaseMessageHolder newInstance(ViewGroup parent, MessageType messageType) {
    return new BaseMessageHolder(getItemView(parent, messageType), messageType);
  }

  public BaseMessageHolder(View itemView, MessageType messageType) {
    super(itemView);
    this.context = itemView.getContext();

    switch (messageType) {
      case GUEST_TEXT_MESSAGE:
      case GUEST_IMAGE_MESSAGE:
      case GUEST_FILE_MESSAGE:
      case GUEST_WEB_MESSAGE:
      case SENDING:
        guestMessageTime = itemView.findViewById(R.id.ch_text_guest_message_time);
        guestMessageTextLayout = itemView.findViewById(R.id.ch_message_content_guest_text);
        break;

      default:
        managerMessageProfileLayout = itemView.findViewById(R.id.ch_layout_manager_message_profile);
        managerMessageAvatar = itemView.findViewById(R.id.ch_avater_manager_message);
        managerMessageTime = itemView.findViewById(R.id.ch_text_manager_message_time);
        managerMessageName = itemView.findViewById(R.id.ch_text_manager_message_name);
        managerMessageTextLayout = itemView.findViewById(R.id.ch_message_content_manager_text);
        break;
    }
    contentLayout = itemView.findViewById(R.id.ch_layout_message_content);
  }

  protected static View getItemView(ViewGroup parent, MessageType messageType) {
    LayoutInflater inflater = LayoutInflater.from(parent.getContext());

    switch (messageType) {
      case GUEST_TEXT_MESSAGE:
      case GUEST_IMAGE_MESSAGE:
      case GUEST_FILE_MESSAGE:
      case GUEST_WEB_MESSAGE:
      case SENDING:
        return inflater.inflate(R.layout.ch_plugin_item_message_guest, parent, false);

      default:
        return inflater.inflate(R.layout.ch_plugin_item_message_manager2, parent, false);
    }
  }

  public void bind(Message message, MessageType messageType, boolean isConnectedMessage) {
    setLayout(message, messageType, isConnectedMessage);
  }

  private void setLayout(Message message, MessageType messageType, boolean isConnectedMessage) {
    switch (messageType) {
      case GUEST_TEXT_MESSAGE:
      case GUEST_IMAGE_MESSAGE:
      case GUEST_FILE_MESSAGE:
      case GUEST_WEB_MESSAGE:
      case SENDING:
        setGuestMessage(message, isConnectedMessage);
        break;

      default:
        setManagerMessage(message, isConnectedMessage);
        break;
    }
  }

  private void setGuestMessage(Message message, boolean isConnectedMessage) {
    if (message != null) {
      guestMessageTime.setVisibility(UIUtils.getVisible(!isConnectedMessage, true));
      guestMessageTime.setText(TimeUtils.getTime(message.getCreatedAt()));

      LinearLayout.LayoutParams params = new LinearLayout.LayoutParams(
          ViewGroup.LayoutParams.MATCH_PARENT,
          ViewGroup.LayoutParams.WRAP_CONTENT);
      params.gravity = Gravity.END;
      contentLayout.setGravity(Gravity.END);
      contentLayout.setLayoutParams(params);
    }
  }

  private void setManagerMessage(Message message, boolean isConnectedMessage) {
    if (message != null) {
      ProfileEntity profile = ChatDataDictionary
          .getInstance()
          .getProfile(message.getPersonType(), message.getPersonId());

      managerMessageProfileLayout.setVisibility(UIUtils.getVisible(!isConnectedMessage, true));
      managerMessageAvatar.set(profile);
      managerMessageTime.setText(TimeUtils.getTime(message.getCreatedAt()));
      managerMessageName.setText(profile.getName());

      LinearLayout.LayoutParams params = new LinearLayout.LayoutParams(
          ViewGroup.LayoutParams.MATCH_PARENT,
          ViewGroup.LayoutParams.WRAP_CONTENT);
      params.leftMargin = (int) Utils.dpToPx(context, 46);
      contentLayout.setLayoutParams(params);
    }
  }
}
